@@ -1,7 +1,7 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.56';
+$Geo::Address::Formatter::VERSION = '1.57';
 use strict;
 use warnings;
 
@@ -211,11 +211,17 @@ sub _postformat {
 
 sub _sanity_cleaning {
     my $self = shift;
-    my $rh_components = shift || return; 
-    if (defined($rh_components->{'postcode'})
-        && (length($rh_components->{'postcode'}) > 20)
-    ){
-        delete $rh_components->{'postcode'};
+    my $rh_components = shift || return;
+    
+    if ( defined($rh_components->{'postcode'}) ){
+        
+        if ( length($rh_components->{'postcode'}) > 20){
+            delete $rh_components->{'postcode'};
+        }
+        elsif($rh_components->{'postcode'} =~ m/\d+;\d+/){
+              # sometimes OSM has postcode ranges
+              delete $rh_components->{'postcode'};
+        }
     }
 
     # catch values containing URLs
@@ -503,7 +509,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.56
+version 1.57
 
 =head1 SYNOPSIS
 
